@@ -4,7 +4,7 @@
 import boto3
 import botocore.exceptions as exceptions
 import sys
-from os import path, system, getenv
+from os import path, system, getenv, rename
 import configparser
 from pprint import pprint
 import argparse
@@ -15,7 +15,7 @@ import six
 from botocore.exceptions import ClientError
 import json
 
-VERSION = "4.1.3"
+VERSION = "4.1.4"
 
 
 def connect(instance: object, args: argparse.Namespace):
@@ -296,13 +296,16 @@ def get_instances(args: argparse.Namespace) -> list:
         else:
             aws_shared_credentials_file = config.read(getenv('HOME') + '/.aws/credentials')[0]
 
-        with open(aws_shared_credentials_file, 'w') as configfile:
-            config.write(configfile)
-
         config.set('mfa', 'aws_access_key_id', sts_access_key_id)
         config.set('mfa', 'aws_secret_access_key', sts_secret_access_key)
         config.set('mfa', 'aws_session_token', sts_session_token)
 
+        with open(aws_shared_credentials_file + '.temp', 'w') as configfile:
+            config.write(configfile)
+
+        rename(aws_shared_credentials_file, aws_shared_credentials_file + ".BAK")
+        rename(aws_shared_credentials_file + '.temp', aws_shared_credentials_file)
+
         if args.region == 'default':  # default='default' was set by parser if none given
             ec2 = boto3.resource('ec2', aws_access_key_id=sts_access_key_id,
                                  aws_secret_access_key=sts_secret_access_key, aws_session_token=sts_session_token)
@@ -339,7 +342,6 @@ def get_instances(args: argparse.Namespace) -> list:
 
 
 def main():
-    """void main"""
     parser = create_parser()
     args = parser.parse_args()
 
